@@ -215,14 +215,14 @@ class CodeDeployClient:
     exceptions: Exceptions
 
     def add_tags_to_on_premises_instances(
-        self, tags: List[TagTypeDef], instanceNames: List[str]
+        self, tags: List["TagTypeDef"], instanceNames: List[str]
     ) -> None:
         """
         [Client.add_tags_to_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codedeploy.html#CodeDeploy.Client.add_tags_to_on_premises_instances)
         """
 
     def batch_get_application_revisions(
-        self, applicationName: str, revisions: List[RevisionLocationTypeDef]
+        self, applicationName: str, revisions: List["RevisionLocationTypeDef"]
     ) -> BatchGetApplicationRevisionsOutputTypeDef:
         """
         [Client.batch_get_application_revisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codedeploy.html#CodeDeploy.Client.batch_get_application_revisions)
@@ -286,7 +286,7 @@ class CodeDeployClient:
         self,
         applicationName: str,
         computePlatform: Literal["Server", "Lambda", "ECS"] = None,
-        tags: List[TagTypeDef] = None,
+        tags: List["TagTypeDef"] = None,
     ) -> CreateApplicationOutputTypeDef:
         """
         [Client.create_application documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codedeploy.html#CodeDeploy.Client.create_application)
@@ -296,12 +296,12 @@ class CodeDeployClient:
         self,
         applicationName: str,
         deploymentGroupName: str = None,
-        revision: RevisionLocationTypeDef = None,
+        revision: "RevisionLocationTypeDef" = None,
         deploymentConfigName: str = None,
         description: str = None,
         ignoreApplicationStopFailures: bool = None,
-        targetInstances: TargetInstancesTypeDef = None,
-        autoRollbackConfiguration: AutoRollbackConfigurationTypeDef = None,
+        targetInstances: "TargetInstancesTypeDef" = None,
+        autoRollbackConfiguration: "AutoRollbackConfigurationTypeDef" = None,
         updateOutdatedInstancesOnly: bool = None,
         fileExistsBehavior: Literal["DISALLOW", "OVERWRITE", "RETAIN"] = None,
     ) -> CreateDeploymentOutputTypeDef:
@@ -312,8 +312,8 @@ class CodeDeployClient:
     def create_deployment_config(
         self,
         deploymentConfigName: str,
-        minimumHealthyHosts: MinimumHealthyHostsTypeDef = None,
-        trafficRoutingConfig: TrafficRoutingConfigTypeDef = None,
+        minimumHealthyHosts: "MinimumHealthyHostsTypeDef" = None,
+        trafficRoutingConfig: "TrafficRoutingConfigTypeDef" = None,
         computePlatform: Literal["Server", "Lambda", "ECS"] = None,
     ) -> CreateDeploymentConfigOutputTypeDef:
         """
@@ -326,19 +326,19 @@ class CodeDeployClient:
         deploymentGroupName: str,
         serviceRoleArn: str,
         deploymentConfigName: str = None,
-        ec2TagFilters: List[EC2TagFilterTypeDef] = None,
-        onPremisesInstanceTagFilters: List[TagFilterTypeDef] = None,
+        ec2TagFilters: List["EC2TagFilterTypeDef"] = None,
+        onPremisesInstanceTagFilters: List["TagFilterTypeDef"] = None,
         autoScalingGroups: List[str] = None,
-        triggerConfigurations: List[TriggerConfigTypeDef] = None,
-        alarmConfiguration: AlarmConfigurationTypeDef = None,
-        autoRollbackConfiguration: AutoRollbackConfigurationTypeDef = None,
-        deploymentStyle: DeploymentStyleTypeDef = None,
-        blueGreenDeploymentConfiguration: BlueGreenDeploymentConfigurationTypeDef = None,
-        loadBalancerInfo: LoadBalancerInfoTypeDef = None,
-        ec2TagSet: EC2TagSetTypeDef = None,
-        ecsServices: List[ECSServiceTypeDef] = None,
-        onPremisesTagSet: OnPremisesTagSetTypeDef = None,
-        tags: List[TagTypeDef] = None,
+        triggerConfigurations: List["TriggerConfigTypeDef"] = None,
+        alarmConfiguration: "AlarmConfigurationTypeDef" = None,
+        autoRollbackConfiguration: "AutoRollbackConfigurationTypeDef" = None,
+        deploymentStyle: "DeploymentStyleTypeDef" = None,
+        blueGreenDeploymentConfiguration: "BlueGreenDeploymentConfigurationTypeDef" = None,
+        loadBalancerInfo: "LoadBalancerInfoTypeDef" = None,
+        ec2TagSet: "EC2TagSetTypeDef" = None,
+        ecsServices: List["ECSServiceTypeDef"] = None,
+        onPremisesTagSet: "OnPremisesTagSetTypeDef" = None,
+        tags: List["TagTypeDef"] = None,
     ) -> CreateDeploymentGroupOutputTypeDef:
         """
         [Client.create_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codedeploy.html#CodeDeploy.Client.create_deployment_group)
@@ -395,7 +395,7 @@ class CodeDeployClient:
         """
 
     def get_application_revision(
-        self, applicationName: str, revision: RevisionLocationTypeDef
+        self, applicationName: str, revision: "RevisionLocationTypeDef"
     ) -> GetApplicationRevisionOutputTypeDef:
         """
         [Client.get_application_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codedeploy.html#CodeDeploy.Client.get_application_revision)
@@ -525,7 +525,7 @@ class CodeDeployClient:
     def list_on_premises_instances(
         self,
         registrationStatus: Literal["Registered", "Deregistered"] = None,
-        tagFilters: List[TagFilterTypeDef] = None,
+        tagFilters: List["TagFilterTypeDef"] = None,
         nextToken: str = None,
     ) -> ListOnPremisesInstancesOutputTypeDef:
         """
@@ -552,7 +552,7 @@ class CodeDeployClient:
         """
 
     def register_application_revision(
-        self, applicationName: str, revision: RevisionLocationTypeDef, description: str = None
+        self, applicationName: str, revision: "RevisionLocationTypeDef", description: str = None
     ) -> None:
         """
         [Client.register_application_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codedeploy.html#CodeDeploy.Client.register_application_revision)
@@ -566,7 +566,7 @@ class CodeDeployClient:
         """
 
     def remove_tags_from_on_premises_instances(
-        self, tags: List[TagTypeDef], instanceNames: List[str]
+        self, tags: List["TagTypeDef"], instanceNames: List[str]
     ) -> None:
         """
         [Client.remove_tags_from_on_premises_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codedeploy.html#CodeDeploy.Client.remove_tags_from_on_premises_instances)
@@ -584,7 +584,7 @@ class CodeDeployClient:
         [Client.stop_deployment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codedeploy.html#CodeDeploy.Client.stop_deployment)
         """
 
-    def tag_resource(self, ResourceArn: str, Tags: List[TagTypeDef]) -> Dict[str, Any]:
+    def tag_resource(self, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
         [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codedeploy.html#CodeDeploy.Client.tag_resource)
         """
@@ -607,19 +607,19 @@ class CodeDeployClient:
         currentDeploymentGroupName: str,
         newDeploymentGroupName: str = None,
         deploymentConfigName: str = None,
-        ec2TagFilters: List[EC2TagFilterTypeDef] = None,
-        onPremisesInstanceTagFilters: List[TagFilterTypeDef] = None,
+        ec2TagFilters: List["EC2TagFilterTypeDef"] = None,
+        onPremisesInstanceTagFilters: List["TagFilterTypeDef"] = None,
         autoScalingGroups: List[str] = None,
         serviceRoleArn: str = None,
-        triggerConfigurations: List[TriggerConfigTypeDef] = None,
-        alarmConfiguration: AlarmConfigurationTypeDef = None,
-        autoRollbackConfiguration: AutoRollbackConfigurationTypeDef = None,
-        deploymentStyle: DeploymentStyleTypeDef = None,
-        blueGreenDeploymentConfiguration: BlueGreenDeploymentConfigurationTypeDef = None,
-        loadBalancerInfo: LoadBalancerInfoTypeDef = None,
-        ec2TagSet: EC2TagSetTypeDef = None,
-        ecsServices: List[ECSServiceTypeDef] = None,
-        onPremisesTagSet: OnPremisesTagSetTypeDef = None,
+        triggerConfigurations: List["TriggerConfigTypeDef"] = None,
+        alarmConfiguration: "AlarmConfigurationTypeDef" = None,
+        autoRollbackConfiguration: "AutoRollbackConfigurationTypeDef" = None,
+        deploymentStyle: "DeploymentStyleTypeDef" = None,
+        blueGreenDeploymentConfiguration: "BlueGreenDeploymentConfigurationTypeDef" = None,
+        loadBalancerInfo: "LoadBalancerInfoTypeDef" = None,
+        ec2TagSet: "EC2TagSetTypeDef" = None,
+        ecsServices: List["ECSServiceTypeDef"] = None,
+        onPremisesTagSet: "OnPremisesTagSetTypeDef" = None,
     ) -> UpdateDeploymentGroupOutputTypeDef:
         """
         [Client.update_deployment_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codedeploy.html#CodeDeploy.Client.update_deployment_group)
