@@ -211,7 +211,7 @@ class ListOnPremisesInstancesPaginator(Boto3Paginator):
     def paginate(
         self,
         registrationStatus: Literal["Registered", "Deregistered"] = None,
-        tagFilters: List[TagFilterTypeDef] = None,
+        tagFilters: List["TagFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListOnPremisesInstancesOutputTypeDef]:
         """
